@@ -11,10 +11,10 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import sys
+import logging
 import os
 import platform
 from subprocess import Popen, PIPE
-import six
 
 from docutils.core import publish_string
 import bcdoc
@@ -28,6 +28,9 @@ from bcdoc.textwriter import TextWriter
 from awscli.argprocess import ParamShorthand
 
 
+LOG = logging.getLogger('awscli.help')
+
+
 class HelpRenderer(object):
     """
     Interface for a help renderer.
@@ -62,13 +65,16 @@ class PosixHelpRenderer(HelpRenderer):
 
     def render(self, contents):
         cmdline = ['rst2man.py']
+        LOG.debug("Running command: %s", cmdline)
         p2 = Popen(cmdline, stdin=PIPE, stdout=PIPE)
-        p2.stdin.write(six.b(contents))
+        p2.stdin.write(contents)
         p2.stdin.close()
         cmdline = ['groff', '-man', '-T', 'ascii']
+        LOG.debug("Running command: %s", cmdline)
         p3 = Popen(cmdline, stdin=p2.stdout, stdout=PIPE)
         pager = self.get_pager()
         cmdline = [pager]
+        LOG.debug("Running command: %s", cmdline)
         p4 = Popen(cmdline, stdin=p3.stdout)
         p4.communicate()
         sys.exit(1)
@@ -191,7 +197,7 @@ class HelpCommand(object):
         # We pass ourselves along so that we can, in turn, get passed
         # to all event handlers.
         bcdoc.clidocevents.generate_events(self.session, self)
-        self.renderer.render(self.doc.fp.getvalue())
+        self.renderer.render(self.doc.getvalue())
 
 
 
